==> qtjambi-qml-debuginfo-macos-6.8.1.jar: sources/QtJambiQml/QQmlTypesExtensionInterface_shell.cpp <==
#include "QQmlTypesExtensionInterface_shell.h"
#include <QtJambi/Cast>

void deleter_QQmlTypesExtensionInterface(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QQmlTypesExtensionInterface")
    QQmlTypesExtensionInterface *_ptr = reinterpret_cast<QQmlTypesExtensionInterface *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QQmlTypesExtensionInterface_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QQmlTypesExtensionInterface_shell) ); }

jmethodID QQmlTypesExtensionInterface_oshell::__shell_javaMethod(int pos) const { return QQmlTypesExtensionInterface_shell::__shell()->javaMethod(typeid(QQmlTypesExtensionInterface), pos); }

// emitting (writeShellDestructor)
QQmlTypesExtensionInterface_shell::~QQmlTypesExtensionInterface_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QQmlTypesExtensionInterface::~QQmlTypesExtensionInterface()", this)
    QQmlTypesExtensionInterface_shell::__shell()->destructed(typeid(QQmlTypesExtensionInterface));
}

// emitting (writeShellConstructor)
QQmlTypesExtensionInterface_shell::QQmlTypesExtensionInterface_shell()
    : QQmlTypesExtensionInterface()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QQmlTypesExtensionInterface::QQmlTypesExtensionInterface_shell()", this)
    QQmlTypesExtensionInterface_shell::__shell()->constructed(typeid(QQmlTypesExtensionInterface));
}

void QQmlTypesExtensionInterface_oshell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QQmlTypesExtensionInterface_oshell*>(ptr)->QQmlTypesExtensionInterface_oshell::__shell()->tryDeleteShell(typeid(QQmlTypesExtensionInterface));
}

// emitting Virtual overrides (virtualFunctions)
void QQmlTypesExtensionInterface_oshell::registerTypes(const char* uri0)
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        QTJAMBI_JAVA_METHOD_CALL("QQmlTypesExtensionInterface::registerTypes(const char*)", this)
        if (JniEnvironmentExceptionHandler __jni_env{300}) {
            QTJAMBI_TRY {
                if(jobject __java_this = QQmlTypesExtensionInterface_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jstring __java_uri0 = qtjambi_cast<jstring>(__jni_env, uri0);
                    __jni_env->CallVoidMethod(__java_this, method_id, __java_uri0);
                    __jni_env.checkException( QTJAMBI_STACKTRACEINFO_NOENV );
                } else {
                    QQmlTypesExtensionInterface_shell::__shell()->warnForMethod("QQmlTypesExtensionInterface::registerTypes(const char*)");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __jni_env.handleException(exn, "QQmlTypesExtensionInterface::registerTypes(const char*)");
            } QTJAMBI_TRY_END
        }
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
void QQmlTypesExtensionInterface_access::__qt_registerTypes_const_char_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring uri0)
{
    QtJambiScope __qtjambi_scope(__this_nativeId);
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    const char* __qt_uri0 = qtjambi_cast<const char*>(__jni_env, __qtjambi_scope, uri0);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        JavaException::raiseQNoImplementationException(__jni_env, "Call of pure virtual method QQmlTypesExtensionInterface::registerTypes(const char * uri)." QTJAMBI_STACKTRACEINFO );
        throw "Call of pure virtual method QQmlTypesExtensionInterface::registerTypes(const char * uri).";
    } else {
        registerTypes(__qt_uri0);
    }
}

// emitting (writeConstructors)
// new QQmlTypesExtensionInterface()
void __qt_construct_QQmlTypesExtensionInterface(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QQmlTypesExtensionInterface()")
    Q_UNUSED(__java_arguments)
    QQmlTypesExtensionInterface *__qt_this = new(__qtjambi_ptr) QQmlTypesExtensionInterface_oshell();
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
}

// QQmlTypesExtensionInterface::QQmlTypesExtensionInterface()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QQmlTypesExtensionInterface_00024Impl_initialize_1native__Lio_qt_qml_QQmlTypesExtensionInterface_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QQmlTypesExtensionInterface::QQmlTypesExtensionInterface()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QQmlTypesExtensionInterface, sizeof(QQmlTypesExtensionInterface_shell), typeid(QQmlTypesExtensionInterface), 0, true, &deleter_QQmlTypesExtensionInterface, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QQmlTypesExtensionInterface_shell
void __qt_destruct_QQmlTypesExtensionInterface(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QQmlTypesExtensionInterface")
    reinterpret_cast<QQmlTypesExtensionInterface_shell*>(ptr)->~QQmlTypesExtensionInterface_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QQmlTypesExtensionInterface::registerTypes(const char*)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QQmlTypesExtensionInterface_00024Impl_00024ConcreteWrapper_registerTypes_1native_1const_1char_1ptr__JLjava_lang_String_2)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId,
 jstring uri0)
{
    QTJAMBI_TRY {
        QQmlTypesExtensionInterface *__qt_this = QtJambiAPI::interfaceFromNativeId<QQmlTypesExtensionInterface>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QQmlTypesExtensionInterface::registerTypes(const char*)", __this_nativeId)
        static_cast<QQmlTypesExtensionInterface_access*>(__qt_this)->__qt_registerTypes_const_char_ptr(__jni_env, __this_nativeId, uri0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QQmlTypesExtensionInterface(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerInterfaceTypeInfo<QQmlTypesExtensionInterface>("QQmlTypesExtensionInterface", "io/qt/qml/QQmlTypesExtensionInterface");
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo{/* 0 */ "registerTypes", "(Ljava/lang/String;)V", FunctionInfo::Abstract}});
    registerConstructorInfos(typeId, 0, &__qt_destruct_QQmlTypesExtensionInterface, {
        ConstructorInfo{&__qt_construct_QQmlTypesExtensionInterface, nullptr}
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QQmlTypesExtensionInterface);
    registerSizeOfShell(typeId, sizeof(QQmlTypesExtensionInterface_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerPolymorphyHandler(typeid(QObject), typeId, [](void *ptr, qintptr& offset) -> bool {
            QObject *object = reinterpret_cast<QObject *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QQmlTypesExtensionInterface* _object = dynamic_cast<QQmlTypesExtensionInterface*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerPolymorphyHandler(typeId, typeid(QObject), [](void *ptr, qintptr& offset) -> bool {
            QQmlTypesExtensionInterface *object = reinterpret_cast<QQmlTypesExtensionInterface *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QObject* _object = dynamic_cast<QObject*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerOwnerFunction(typeId, [](const void *ptr)->const QObject*{
        const QQmlTypesExtensionInterface *object = reinterpret_cast<const QQmlTypesExtensionInterface *>(ptr);
        const QObject* _result = nullptr;
        QTJAMBI_TRY_ANY {
            _result = dynamic_cast<const QObject*>(object);
        } QTJAMBI_CATCH_ANY{
        } QTJAMBI_TRY_END
        return _result;
    });
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-qml-debuginfo-macos-6.8.5.jar: sources/QtJambiQml/QQmlTypesExtensionInterface_shell.cpp <==
#include "QQmlTypesExtensionInterface_shell.h"
#include <QtJambi/Cast>

void deleter_QQmlTypesExtensionInterface(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QQmlTypesExtensionInterface")
    QQmlTypesExtensionInterface *_ptr = reinterpret_cast<QQmlTypesExtensionInterface *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QQmlTypesExtensionInterface_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QQmlTypesExtensionInterface_shell) ); }

jmethodID QQmlTypesExtensionInterface_oshell::__shell_javaMethod(int pos) const { return QQmlTypesExtensionInterface_shell::__shell()->javaMethod(typeid(QQmlTypesExtensionInterface), pos); }

// emitting (writeShellDestructor)
QQmlTypesExtensionInterface_shell::~QQmlTypesExtensionInterface_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QQmlTypesExtensionInterface::~QQmlTypesExtensionInterface()", this)
    QQmlTypesExtensionInterface_shell::__shell()->destructed(typeid(QQmlTypesExtensionInterface));
}

// emitting (writeShellConstructor)
QQmlTypesExtensionInterface_shell::QQmlTypesExtensionInterface_shell()
    : QQmlTypesExtensionInterface()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QQmlTypesExtensionInterface::QQmlTypesExtensionInterface_shell()", this)
    QQmlTypesExtensionInterface_shell::__shell()->constructed(typeid(QQmlTypesExtensionInterface));
}

void QQmlTypesExtensionInterface_oshell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QQmlTypesExtensionInterface_oshell*>(ptr)->QQmlTypesExtensionInterface_oshell::__shell()->tryDeleteShell(typeid(QQmlTypesExtensionInterface));
}

// emitting Virtual overrides (virtualFunctions)
void QQmlTypesExtensionInterface_oshell::registerTypes(const char* uri0)
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        QTJAMBI_JAVA_METHOD_CALL("QQmlTypesExtensionInterface::registerTypes(const char*)", this)
        if (JniEnvironmentExceptionHandler __jni_env{300}) {
            QTJAMBI_TRY {
                if(jobject __java_this = QQmlTypesExtensionInterface_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jstring __java_uri0 = qtjambi_cast<jstring>(__jni_env, uri0);
                    __jni_env->CallVoidMethod(__java_this, method_id, __java_uri0);
                    __jni_env.checkException( QTJAMBI_STACKTRACEINFO_NOENV );
                } else {
                    QQmlTypesExtensionInterface_shell::__shell()->warnForMethod("QQmlTypesExtensionInterface::registerTypes(const char*)");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __jni_env.handleException(exn, this, "QQmlTypesExtensionInterface::registerTypes(const char*)");
            } QTJAMBI_TRY_END
        }
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
void QQmlTypesExtensionInterface_access::__qt_registerTypes_const_char_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring uri0)
{
    QtJambiScope __qtjambi_scope(__this_nativeId);
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    const char* __qt_uri0 = qtjambi_cast<const char*>(__jni_env, __qtjambi_scope, uri0);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        JavaException::raiseQNoImplementationException(__jni_env, "Call of pure virtual method QQmlTypesExtensionInterface::registerTypes(const char * uri)." QTJAMBI_STACKTRACEINFO );
        throw "Call of pure virtual method QQmlTypesExtensionInterface::registerTypes(const char * uri).";
    } else {
        registerTypes(__qt_uri0);
    }
}

// emitting (writeConstructors)
// new QQmlTypesExtensionInterface()
void __qt_construct_QQmlTypesExtensionInterface(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QQmlTypesExtensionInterface()")
    Q_UNUSED(__java_arguments)
    QQmlTypesExtensionInterface *__qt_this = new(__qtjambi_ptr) QQmlTypesExtensionInterface_oshell();
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
}

// QQmlTypesExtensionInterface::QQmlTypesExtensionInterface()
extern "C" JNIEXPORT void JNICALL Java_io_qt_qml_QQmlTypesExtensionInterface_00024Impl_initialize_1native__Lio_qt_qml_QQmlTypesExtensionInterface_2
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QQmlTypesExtensionInterface::QQmlTypesExtensionInterface()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QQmlTypesExtensionInterface, sizeof(QQmlTypesExtensionInterface_shell), typeid(QQmlTypesExtensionInterface), 0, true, &deleter_QQmlTypesExtensionInterface, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QQmlTypesExtensionInterface_shell
void __qt_destruct_QQmlTypesExtensionInterface(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QQmlTypesExtensionInterface")
    reinterpret_cast<QQmlTypesExtensionInterface_shell*>(ptr)->~QQmlTypesExtensionInterface_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QQmlTypesExtensionInterface::registerTypes(const char*)
extern "C" JNIEXPORT void JNICALL Java_io_qt_qml_QQmlTypesExtensionInterface_00024Impl_00024ConcreteWrapper_registerTypes_1native_1const_1char_1ptr__JLjava_lang_String_2
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId,
 jstring uri0)
{
    QTJAMBI_TRY {
        QQmlTypesExtensionInterface *__qt_this = QtJambiAPI::interfaceFromNativeId<QQmlTypesExtensionInterface>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QQmlTypesExtensionInterface::registerTypes(const char*)", __this_nativeId)
        static_cast<QQmlTypesExtensionInterface_access*>(__qt_this)->__qt_registerTypes_const_char_ptr(__jni_env, __this_nativeId, uri0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QQmlTypesExtensionInterface(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerInterfaceTypeInfo<QQmlTypesExtensionInterface>("QQmlTypesExtensionInterface", "io/qt/qml/QQmlTypesExtensionInterface");
    registerFunctionInfos(typeId, {
        FunctionInfo{/* 0 */ "registerTypes", "(Ljava/lang/String;)V", FunctionInfo::Abstract}});
    registerConstructorInfos(typeId, 0, &__qt_destruct_QQmlTypesExtensionInterface, {
        ConstructorInfo{&__qt_construct_QQmlTypesExtensionInterface, nullptr}
    });
    registerDeleter(typeId, &deleter_QQmlTypesExtensionInterface);
    registerSizeOfShell(typeId, sizeof(QQmlTypesExtensionInterface_shell));
    registerPolymorphyHandler(typeid(QObject), typeId, [](void *ptr, qintptr& offset) -> bool {
            QObject *object = reinterpret_cast<QObject *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QQmlTypesExtensionInterface* _object = dynamic_cast<QQmlTypesExtensionInterface*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerPolymorphyHandler(typeId, typeid(QObject), [](void *ptr, qintptr& offset) -> bool {
            QQmlTypesExtensionInterface *object = reinterpret_cast<QQmlTypesExtensionInterface *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QObject* _object = dynamic_cast<QObject*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerOwnerFunction(typeId, [](const void *ptr)->const QObject*{
        const QQmlTypesExtensionInterface *object = reinterpret_cast<const QQmlTypesExtensionInterface *>(ptr);
        const QObject* _result = nullptr;
        QTJAMBI_TRY_ANY {
            _result = dynamic_cast<const QObject*>(object);
        } QTJAMBI_CATCH_ANY{
        } QTJAMBI_TRY_END
        return _result;
    });
}
